#delimit ;
*analysis_newly.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\do\newlyweds\analysis_newly.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;
set matsize 6000 ;


#delimit cr

use "F:\Schwartz\cps_historical\data\newly_tabpub.dta"

gen cps = (cen == 0)


tab y cps [w=freq]
display _N



tab yc
bysort cps: tab y yc


display _N

preserve
collapse (sum) freq, by(y cps)
display _N
restore



*******************************
* SECTION 1: CREATE VARIABLES *
*******************************




   ***Look at the file

      tab y cps [w=freq]



   ***homogamy

      gen h = (hed == wed)


   ***Education specific homogamy

      gen h1 = (hed == wed & hed == 1)
      gen h2 = (hed == wed & hed == 2)
      gen h3 = (hed == wed & hed == 3)
      gen h4 = (hed == wed & hed == 4)
      gen h5 = (hed == wed & hed == 5)



   ***Make the crossing variables

       gen dc1 = 0
       replace dc1 = 1 if (wed < 2 & hed>= 2) | (hed< 2 & wed >= 2)

       gen dc2 = 0
       replace dc2 = 1 if (wed < 3 & hed>= 3) | (hed< 3 & wed >= 3)

       gen dc3 = 0
       replace dc3= 1 if (wed < 4 & hed>= 4) | (hed< 4 & wed >= 4)

       gen dc4 = 0
       replace dc4 = 1 if (wed < 5 & hed>= 5) | (hed< 5 & wed >= 5)


       tab y dc1 [w=freq]



   ***Make a uniform association parameter.


      gen hl = .
      replace hl = 8    if hed == 1
      replace hl = 10.5 if hed == 2
      replace hl = 12   if hed == 3
      replace hl = 14   if hed == 4
      replace hl = 17   if hed == 5

      gen wl = .
      replace wl = 8    if wed == 1
      replace wl = 10.5 if wed == 2
      replace wl = 12   if wed == 3
      replace wl = 14   if wed == 4
      replace wl = 17   if wed == 5


   ***The uniform association parameter is hl*wl

      gen ua = hl*wl



   ****Generate hypergamy parameter

       gen hyp = (hed>wed)



  ***Two-way interactions

     *HY and WY

     foreach num of numlist 1960 1970 1971 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
       local i = 2
        while `i' <= 5 {
           gen h`i'y`num' = (hedc == `i' & y == `num')
           gen w`i'y`num' = (wedc == `i' & y == `num')
       local i = `i' + 1
       }
     }


      *HW

       local i = 2
        while `i' <= 5 {
         local j = 2
          while `j' <= 5 {
           gen h`i'w`j' = (hedc == `i' & wedc == `j')
         local j = `j' + 1
         }
       local i = `i' + 1
       }


      *HCPS and WCPS

       local i = 2
        while `i' <= 5 {
           gen h`i'cen = (hedc == `i' & cen == 1)
           gen w`i'cen = (wedc == `i' & cen == 1)
       local i = `i' + 1
       }



      *YCPS

     foreach num of numlist 1960 1970 1971 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
         gen y`num'cen = (cen == 1 & y == `num')
     }



   ***Make a three way interaction for the marginals of husband's and
   ***wife's education by year and data source


     foreach num of numlist 1960 1970 1971 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
       local i = 1
        while `i' <= 5 {
           gen h`i'y`num'cen = (hedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }

     foreach num of numlist 1960 1970 1971 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
       local i = 1
        while `i' <= 5 {
           gen w`i'y`num'cen = (wedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }


       local i = 1
        while `i' <= 5 {
         local j = 1
          while `j' <= 5 {
           gen h`i'w`j'ycen = (hedc == `i' & wedc == `j' & cen == 1)
         local j = `j' + 1
         }
       local i = `i' + 1
       }



     *H*YC
     *UA*YC
      foreach num of numlist 1960 1970 1972 1977 1982 1987 1992 {
           gen yc`num' = (yc == `num')
           gen hyc`num' = (h == 1 & yc == `num')
           gen uyc`num' = (ua * yc`num')
     }




     *DC*YC
      foreach num of numlist 1960 1970 1972 1977 1982 1987 1992 {
      local i = 1
       while `i' <= 4 {
           gen dc`i'yc`num' = (dc`i' == 1 & yc == `num')
      local i = `i' + 1
      }
     }

     *HomSpecific*Census
     *HomSpecific*Newed

       local i = 1
        while `i' <= 5 {
           gen hm`i'cen = (h`i' == 1 & cen   == 1)
           gen hm`i'new = (h`i' == 1 & newed == 1)
       local i = `i' + 1
       }

     *Hom/UA*Census

      gen hcen = (h == 1 & cen   == 1)
      gen hnew = (h == 1 & newed == 1)
      gen uacen = (ua * cen)

     *DC*Census

       local i = 1
        while `i' <= 4 {
           gen dc`i'cen = (dc`i' == 1 & cen   == 1)
       local i = `i' + 1
       }




   set matsize 6000






***************************************
* SECTION 2: MAKE MACROS FOR MODELING *
***************************************




   #delimit ;

   local hycen "h2y1980cen
                h3y1980cen
                h4y1980cen
                h5y1980cen";

   local wycen "w2y1980cen
                w3y1980cen
                w4y1980cen
                w5y1980cen";


   local whc "h2w2ycen
              h2w3ycen
              h2w4ycen
              h2w5ycen
              h3w2ycen
              h3w3ycen
              h3w4ycen
              h3w5ycen
              h4w2ycen
              h4w3ycen
              h4w4ycen
              h4w5ycen
              h5w2ycen
              h5w3ycen
              h5w4ycen
              h5w5ycen" ;



   local hwf "h2w2
              h2w3
              h2w4
              h2w5
              h3w2
              h3w3
              h3w4
              h3w5
              h4w2
              h4w3
              h4w4
              h4w5
              h5w2
              h5w3
              h5w4
              h5w5" ;








****************************************
* HOMOGAMY                             *
**************************************** ;




preserve ;



  *** MODEL: HYS, WYS, HWS, OY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;





  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  hcen     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1940 = exp(f40h)

      foreach num of numlist 1960 1970 1972 1977 1982 1987 1992 {
         quietly gen e_hm`num' = exp(f40h + f03hyc`num')
       }




   drop f40* f03*



#delimit ;



****************************************
* UNIFORM ASSOCIATION                  *
**************************************** ;



  *** MODEL: HYS, WYS, HWS, UAY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform association*/
                     uyc???? ua


                  , family(poisson) link(log) offset(neglnzi)  ;




    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  uacen    /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform assocation*/
                     uyc???? ua

                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_uam1940 = exp(f40ua)

      foreach num of numlist 1960 1970 1972 1977 1982 1987 1992 {
         quietly gen e_uam`num' = exp(f40ua + f03uyc`num')
       }



   drop f40* f03*

#delimit ;




****************************************
* CROSSINGS                            *
**************************************** ;


  *** MODEL: HYS, WYS, HWS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   dc?yc????


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  dc?cen   /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   dc?yc???? dc1 dc2 dc3 dc4


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/4 {

         gen e_dc`dc'm1940 = exp(f40dc`dc')

      foreach num of numlist 1960 1970 1972 1977 1982 1987 1992 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03dc`dc'yc`num')
         }


     }



   drop f40* f03*





  *** GRAPH  ***

    keep e_h* e_ua* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_hm e_uam  e_dc1m e_dc2m e_dc3m e_dc4m
                                     , i(id) j(year) ;

    #delimit cr


   recode year 1972=1972.5 1982=1982.5 1992=1992.5


      lab var e_hm    "HY WY HW HmY"
      lab var e_uam   "HY WY HW UaY"
      label var e_dc1m "<10/10+"
      label var e_dc2m "<12/12+"
      label var e_dc3m "<13/13+"
      label var e_dc4m "<16/16+"



    cd "F:\Schwartz\cps_historical\graphs"


    ***HOMOGAMY***

    #delimit ;
    twoway connected e_hm year, yscale(log) c(l) clstyle(p2 p2 p2 p2 p2 p2)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("Odds of ") sub("Prev M, Women 18-40, WEIGHTED")
                                    ytitle("Odds of homogamy") xtitle("year") ;
    #delimit cr

    graph export analysis_newly1.wmf, replace




    ***UAY***

    #delimit ;
    twoway connected e_uam year, yscale(log r(1.05 1.15)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.05(.03)1.15)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("HY WY HW UaY") sub("Prev M, Women 18-40, WEIGHTED")
                                    ytitle("Uniform Association") xtitle("year") ;
    #delimit cr

    graph export analysis_newly2.wmf, replace





    ***CROSSINGS***


    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc1m e_dc2m e_dc3m e_dc4m year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("CPS, Census, Women 18-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_newly3.wmf, replace




      sort year
      foreach var of varlist e_hm e_uam e_dc1m e_dc2m e_dc3m e_dc4m  {
       rename `var' `var'_new
      }
      save "F:\Schwartz\cps_historical\data\analysis_newly.dta", replace




#delimit ;


restore ;



preserve ;

***Just for the census ;


keep if cen == 1 ;


  *** MODEL: HYS, WYS, HWS, OY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;





  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1940 = exp(f40h)

      foreach num of numlist 1960 1970 1982 {
         quietly gen e_hm`num' = exp(f40h + f03hyc`num')
       }




   drop f40* f03*




#delimit ;



****************************************
* CROSSINGS                            *
**************************************** ;


  *** MODEL: HYS, WYS, HWS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/


                  /* crossings*/
                   dc?yc????


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/


                  /* crossings*/
                   dc?yc???? dc1 dc2 dc3 dc4


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/4 {

         gen e_dc`dc'm1940 = exp(f40dc`dc')

      foreach num of numlist 1960 1970 1982 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03dc`dc'yc`num')
         }


     }



   drop f40* f03*





  *** GRAPH  ***

    keep e_h* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_hm e_dc1m e_dc2m e_dc3m e_dc4m
                                     , i(id) j(year) ;

    #delimit cr




      lab var e_hm    "HY WY HW HmY"
      label var e_dc1m "<10/10+"
      label var e_dc2m "<12/12+"
      label var e_dc3m "<13/13+"
      label var e_dc4m "<16/16+"




    cd "F:\Schwartz\cps_historical\graphs"


    ***HOMOGAMY***

    #delimit ;
    twoway connected e_hm year, yscale(log) c(l) clstyle(p2 p2 p2 p2 p2 p2)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("Odds of ") sub("Prev M, Women 18-40, WEIGHTED")
                                    ytitle("Odds of homogamy") xtitle("year") ;
    #delimit cr

    graph export analysis_newly4.wmf, replace




    ***CROSSINGS***


    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc1m e_dc2m e_dc3m e_dc4m year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("Census only, Women 18-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_newly5.wmf, replace

    tempfile dc_cen
    sort y
    save `dc_cen'


restore


preserve

#delimit ;

***Just for the CPS ;


keep if cen == 0 ;


  *** MODEL: HYS, WYS, HWS, OY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;





  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                  /* homogamy*/
                   hyc???? h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1972 = exp(f40h)

      foreach num of numlist 1977 1982 1987 1992 {
         quietly gen e_hm`num' = exp(f40h + f03hyc`num')
       }




   drop f40* f03*



#delimit ;



****************************************
* CROSSINGS                            *
**************************************** ;


  *** MODEL: HYS, WYS, HWS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/


                  /* crossings*/
                   dc?yc????


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/


                  /* crossings*/
                   dc?yc???? dc1 dc2 dc3 dc4


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/4 {

         gen e_dc`dc'm1972 = exp(f40dc`dc')

      foreach num of numlist 1977 1982 1987 1992 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03dc`dc'yc`num')
         }


     }



   drop f40* f03*





  *** GRAPH  ***

    keep e_h* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_hm e_dc1m e_dc2m e_dc3m e_dc4m
                                     , i(id) j(year) ;

    #delimit cr




      lab var e_hm    "HY WY HW HmY"
      label var e_dc1m "<10/10+"
      label var e_dc2m "<12/12+"
      label var e_dc3m "<13/13+"
      label var e_dc4m "<16/16+"



    cd "F:\Schwartz\cps_historical\graphs"


    ***HOMOGAMY***

    #delimit ;
    twoway connected e_hm year, yscale(log) c(l) clstyle(p2 p2 p2 p2 p2 p2)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("Odds of ") sub("Prev M, Women 18-40, WEIGHTED")
                                    ytitle("Odds of homogamy") xtitle("year") ;
    #delimit cr

    graph export analysis_newly6.wmf, replace




    ***CROSSINGS***


    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc1m e_dc2m e_dc3m e_dc4m year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("Census only, Women 18-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_newly7.wmf, replace

restore


preserve

#delimit ;

***Just for the CPS ;


keep if cen == 0 ;


  *** MODEL: HYS, WYS, HWS, OY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;





  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1971 = exp(f40h)

     foreach num of numlist 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
         quietly gen e_hm`num' = exp(f40h + f03_IyXh_`num')
       }




   drop f40* f03*



#delimit ;



****************************************
* CROSSINGS                            *
**************************************** ;


  *** MODEL: HYS, WYS, HWS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/


                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/


                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/4 {

         gen e_dc`dc'm1971 = exp(f40dc`dc')

     foreach num of numlist 1973/1977 1979/1983 1985/1988 1990 1992 1994 1995 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03_IyXdc`dc'_`num')
         }


     }



   drop f40* f03*





  *** GRAPH  ***

    keep e_h* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_hm e_dc1m e_dc2m e_dc3m e_dc4m
                                     , i(id) j(year) ;

    #delimit cr


    sort y

      lab var e_hm    "HY WY HW HmY"
      label var e_dc1m "<10/10+"
      label var e_dc2m "<12/12+"
      label var e_dc3m "<13/13+"
      label var e_dc4m "<16/16+"



    cd "F:\Schwartz\cps_historical\graphs"

    foreach var of varlist e_hm e_dc1m e_dc2m e_dc3m e_dc4m {
     rename `var' `var'_cps
    }


    merge year using `dc_cen'
    sort year



    ***HOMOGAMY***

    #delimit ;
    twoway connected e_hm e_hm_cps year, yscale(log) c(l) clstyle(p2 p2 p2 p2 p2 p2)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("Odds of ") sub("Prev M, Women 18-40, WEIGHTED")
                                    ytitle("Odds of homogamy") xtitle("year") ;
    #delimit cr

    graph export analysis_newly6.wmf, replace




    ***CROSSINGS***


    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc1m e_dc1m_cps e_dc2m e_dc2m_cps year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("Census only, Women 18-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_newly7.wmf, replace

    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc3m e_dc3m_cps e_dc4m e_dc4m_cps year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("Census only, Women 18-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_newly8.wmf, replace

