#delimit ;
*analysis_prev.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\do\analysis_prev.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;
set matsize 6000 ;



#delimit cr


   use "F:\Schwartz\cps_historical\data\prevmar_tabpub.dta"

   gen cps = (cen == 0)




tab y cps [w=freq]


display _N

preserve
collapse (sum) freq, by(y cps)
display _N
restore



*******************************
* SECTION 1: CREATE VARIABLES *
*******************************




   ***Look at the file

      tab y cps [w=freq]





   ***homogamy

      gen h = (hed == wed)


   ***Education specific homogamy

      gen h1 = (hed == wed & hed == 1)
      gen h2 = (hed == wed & hed == 2)
      gen h3 = (hed == wed & hed == 3)
      gen h4 = (hed == wed & hed == 4)
      gen h5 = (hed == wed & hed == 5)



   ***Make the crossing variables

       gen dc1 = 0
       replace dc1 = 1 if (wed < 2 & hed>= 2) | (hed< 2 & wed >= 2)

       gen dc2 = 0
       replace dc2 = 1 if (wed < 3 & hed>= 3) | (hed< 3 & wed >= 3)

       gen dc3 = 0
       replace dc3= 1 if (wed < 4 & hed>= 4) | (hed< 4 & wed >= 4)

       gen dc4 = 0
       replace dc4 = 1 if (wed < 5 & hed>= 5) | (hed< 5 & wed >= 5)




   ***Make a uniform association parameter.


      gen hl = .
      replace hl = 8    if hed == 1
      replace hl = 10.5 if hed == 2
      replace hl = 12   if hed == 3
      replace hl = 14   if hed == 4
      replace hl = 17   if hed == 5

      gen wl = .
      replace wl = 8    if wed == 1
      replace wl = 10.5 if wed == 2
      replace wl = 12   if wed == 3
      replace wl = 14   if wed == 4
      replace wl = 17   if wed == 5


   ***The uniform association parameter is hl*wl

      gen ua = hl*wl



   ****Generate hypergamy parameter

       gen hyp = (hed>wed)


       tab hedc wedc [w=freq] if hyp == 1


  ***Two-way interactions

     *HY and WY

     foreach num of numlist 1960 1962 1964/2003 {
       local i = 2
        while `i' <= 5 {
           gen h`i'y`num' = (hedc == `i' & y == `num')
           gen w`i'y`num' = (wedc == `i' & y == `num')
       local i = `i' + 1
       }
     }


      *HW

       local i = 2
        while `i' <= 5 {
         local j = 2
          while `j' <= 5 {
           gen h`i'w`j' = (hedc == `i' & wedc == `j')
         local j = `j' + 1
         }
       local i = `i' + 1
       }


      *HCPS and WCPS

       local i = 2
        while `i' <= 5 {
           gen h`i'cen = (hedc == `i' & cen == 1)
           gen w`i'cen = (wedc == `i' & cen == 1)
       local i = `i' + 1
       }



      *YCPS

     foreach num of numlist 1960 1970 1980 1990 2000 {
         gen y`num'cen = (cen == 1 & y == `num')
     }




   ***Make a three way interaction for the marginals of husband's and
   ***wife's education by year and data source


     foreach num of numlist 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 5 {
           gen h`i'y`num'cen = (hedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }

     foreach num of numlist 1940 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 5 {
           gen w`i'y`num'cen = (wedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }


       local i = 1
        while `i' <= 5 {
         local j = 1
          while `j' <= 5 {
           gen h`i'w`j'ycen = (hedc == `i' & wedc == `j' & cen == 1)
         local j = `j' + 1
         }
       local i = `i' + 1
       }



     *HomSpecific*Y

     foreach num of numlist 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 5 {
           gen hm`i'y`num' = (h`i' == 1 & y == `num')
       local i = `i' + 1
       }
     }



     *Hm*Y
     foreach num of numlist 1960 1962 1964/2003 {
           gen oy`num' = (h == 1 & y == `num')
     }



     *HomSpecific*Census

       local i = 1
        while `i' <= 5 {
           gen hm`i'cen = (h`i' == 1 & cen   == 1)
       local i = `i' + 1
       }

     *Hom/UA*Census

      gen hcen = (h == 1 & cen   == 1)
      gen uacen = (ua * cen)

     *DC*Census

       local i = 1
        while `i' <= 4 {
           gen dc`i'cen = (dc`i' == 1 & cen   == 1)
       local i = `i' + 1
       }




   set matsize 6000



***************************************
* SECTION 2: MAKE MACROS FOR MODELING *
***************************************





   #delimit ;

   local hycen "h2y1970cen
                h2y1980cen
                h2y1990cen
                h2y2000cen
                h3y1970cen
                h3y1980cen
                h3y1990cen
                h3y2000cen
                h4y1970cen
                h4y1980cen
                h4y1990cen
                h4y2000cen
                h5y1970cen
                h5y1980cen
                h5y1990cen
                h5y2000cen" ;

   local wycen "w2y1970cen
                w2y1980cen
                w2y1990cen
                w2y2000cen
                w3y1970cen
                w3y1980cen
                w3y1990cen
                w3y2000cen
                w4y1970cen
                w4y1980cen
                w4y1990cen
                w4y2000cen
                w5y1970cen
                w5y1980cen
                w5y1990cen
                w5y2000cen" ;


   local whc "h2w2ycen
              h2w3ycen
              h2w4ycen
              h2w5ycen
              h3w2ycen
              h3w3ycen
              h3w4ycen
              h3w5ycen
              h4w2ycen
              h4w3ycen
              h4w4ycen
              h4w5ycen
              h5w2ycen
              h5w3ycen
              h5w4ycen
              h5w5ycen" ;


   *HW terms dropped: 23, 34, 42, 54, 55
   * due to collinearity ;

   local hw  "h2w2
              h2w4
              h2w5
              h3w2
              h3w3
              h3w5
              h4w3
              h4w4
              h4w5
              h5w2
              h5w3" ;


   local hwf "h2w2
              h2w3
              h2w4
              h2w5
              h3w2
              h3w3
              h3w4
              h3w5
              h4w2
              h4w3
              h4w4
              h4w5
              h5w2
              h5w3
              h5w4
              h5w5" ;







****************************************
* HOMOGAMY                             *
**************************************** ;




preserve ;



  *** MODEL: HYS, WYS, OS, OY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  `whc'    /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;






  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  hcen     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr


    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1940 = exp(f40h)

       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_hm`num' = exp(f40h + f03_IyXh_`num')
       }


       gen e_h1940 = exp(f40h)
       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_h`num' = exp(f40h + f40_IyXh_`num')
       }




   drop f40* f03*



#delimit ;



****************************************
* UNIFORM ASSOCIATION                  *
**************************************** ;



  *** MODEL: HYS, WYS, UAS, UAY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform association*/
                   i.y*ua


                  , family(poisson) link(log) offset(neglnzi)  ;




    matrix b=e(b) ;
    svmat b, n(eqcol) ;



  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  uacen    /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform assocation*/
                   i.y*ua


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_uam1940 = exp(f40ua)

       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_uam`num' = exp(f40ua + f03_IyXua_`num')
       }


       gen e_ua1940 = exp(f40ua)
       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_ua`num' = exp(f40ua + f40_IyXua_`num')
       }



   drop f40* f03*

#delimit ;




****************************************
* CROSSINGS                            *
**************************************** ;



  *** MODEL: HYS, WYS, CS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'          /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  dc?cen   /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/4 {

         gen e_dc`dc'm1940 = exp(f40dc`dc')

         foreach num of numlist 1960 1962 1964/2003 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03_IyXdc`dc'_`num')
         }


         gen e_dc`dc'1940 = exp(f40dc`dc')
         foreach num of numlist 1960 1962 1964/2003 {
           quietly gen e_dc`dc'`num' = exp(f40dc`dc' + f40_IyXdc`dc'_`num')
         }

     }



   drop f40* f03*








  *** GRAPH  ***

    keep e_h* e_ua* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_h e_hm e_ua e_uam e_dc1 e_dc2 e_dc3 e_dc4
                                     e_dc1m e_dc2m e_dc3m e_dc4m
                                     , i(id) j(year) ;

    #delimit cr



      lab var e_h     "HY WY HmY"
      lab var e_hm    "HY WY HW HmY"
      lab var e_ua    "HY WY UaY"
      lab var e_uam   "HY WY HW UaY"
      label var e_dc1m "<10/10-11"
      label var e_dc2m "10-11/12"
      label var e_dc3m "12/13-15"
      label var e_dc4m "13-15/16+"



    cd "F:\Schwartz\cps_historical\graphs"


    ***HOMOGAMY***

    #delimit ;
    twoway connected e_hm e_h year, yscale(log r(3 4.5)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(3(.5)4.5)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("Odds of Homogamy") sub("Prev M, Women 16-40, WEIGHTED")
                                    ytitle("Odds of homogamy") xtitle("year") ;
    #delimit cr

    graph export analysis_prev1.wmf, replace




    ***UAY***

    #delimit ;
    twoway connected e_uam year, yscale(log r(1.05 1.15)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.05(.03)1.15)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("HY WY HW UaY") sub("Prev M, Women 16-40, WEIGHTED")
                                    ytitle("Uniform Association") xtitle("year") ;
    #delimit cr

    graph export analysis_prev2.wmf, replace





    ***CROSSINGS***


    cd "F:\Schwartz\cps_historical\graphs"

    #delimit ;
    twoway connected e_dc1m e_dc2m e_dc3m e_dc4m year, yscale(log) c(llll) clstyle(p1 p2 p3 p13)  mstyle(p1 p2 p3 p13)
                               xlabel(#10) title("HY WY HW CY") sub("CPS, Census, Women 16-40, WEIGHTED")
                               ytitle("Odds of crossing") xtitle("year") ;
    #delimit cr

    graph export analysis_prev3.wmf, replace





      sort year
      foreach var of varlist e_hm e_uam e_dc1m e_dc2m e_dc3m e_dc4m {
       rename `var' `var'_prev
      }
      save "F:\Schwartz\cps_historical\data\analysis_prev.dta", replace




#delimit ;




***************************************************
* LOOK AT DIFFERENCES IN CROSSINGS BY DATA SOURCE *
*************************************************** ;





****************************************
* PREFERRED MODEL                      *
**************************************** ;



restore ;


#delimit ;




#delimit ;

 gen f03 = freq ;

    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* hypergamy, crossings*/
                   i.y*dc1  i.y*dc2  i.y*dc3  i.y*dc4
                   if cps == 0

                  , family(poisson) link(log) offset(neglnzi)  ;


       matrix b=e(b) ;
       svmat b, n(eqcol) ;


****************************************
* PREFERRED MODEL WITHOUT HW           *
**************************************** ;




   gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* hypergamy, crossings*/
                   i.y*dc1  i.y*dc2  i.y*dc3  i.y*dc4
                   if cps == 0


                  , family(poisson) link(log) offset(neglnzi)  ;

       matrix b=e(b) ;
       svmat b, n(eqcol) ;



    #delimit cr


       local i = 1
        while `i' <= 4 {

         gen e_dc`i'cen1940 = exp(f40dc`i')

          foreach num of numlist 1960 1970 1980 1990 2000 {
            quietly gen e_dc`i'cen`num' = exp(f40dc`i' + f03_IyXdc`i'_`num')
          }

       local i = `i' + 1
       }

       local i = 1
        while `i' <= 4 {

          foreach num of numlist 1940 1960 1970 1980 1990 2000 {
            quietly gen oe`i'`num' = e_dc`i'cen`num'
            drop e_dc`i'cen`num'
            quietly egen e_dc`i'cen`num' = mean(oe`i'`num')
            drop oe`i'`num'
          }

       local i = `i' + 1
       }



   drop f03* f40*


#delimit ;


****************************************
* HOMOGAMY                             *
**************************************** ;




  **********
  * CENSUS *
  **********




  *** MODEL: HYS, WYS, HWS, HWN, HomY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/

                  /* homogamy*/
                   i.y*h if cps == 0


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* homogamy*/
                   i.y*h if cps == 0


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen xe_hcen1940 = exp(f40h)

         foreach num of numlist 1960 1970 1980 1990 2000 {
         quietly gen xe_hcen`num' = exp(f40h + f03_IyXh_`num')
       }

         foreach num of numlist 1940 1960 1970 1980 1990 2000 {
         quietly egen e_hcen`num' = mean(xe_hcen`num')
       }




   drop f40* f03*


***********
* NOW CPS *
***********

#delimit ;


 keep if cps == 1 ;

 gen f03 = freq ;

    xi: glm f03
                 /*marginals*/
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  i.hed*i.wed     /*HW*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* hypergamy, crossings*/
                   i.y*dc1  i.y*dc2  i.y*dc3  i.y*dc4
                   if cps == 1

                  , family(poisson) link(log) offset(neglnzi)  ;


       matrix b=e(b) ;
       svmat b, n(eqcol) ;


****************************************
* PREFERRED MODEL WITHOUT HW           *
**************************************** ;




   gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* hypergamy, crossings*/
                   i.y*dc1  i.y*dc2  i.y*dc3  i.y*dc4
                   if cps == 1


                  , family(poisson) link(log) offset(neglnzi)  ;

       matrix b=e(b) ;
       svmat b, n(eqcol) ;



    #delimit cr


       local i = 1
        while `i' <= 4 {

         gen e_dc`i'cps1962 = exp(f40dc`i')

          foreach num of numlist 1964/2003 {
            quietly gen e_dc`i'cps`num' = exp(f40dc`i' + f03_IyXdc`i'_`num')
          }

       local i = `i' + 1
       }


   drop f03* f40*


   #delimit ;





  **********
  * CPS    *
  **********


  #delimit ;


  *** MODEL: HYS, WYS, HWS, HWN, HomY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/

                  /* homogamy*/
                   i.y*h if cps == 1


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y

                 /*all two-way interactions, HY WY HW HS WS SY HN WN*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/

                 /*three-way interactions, HWS HYS WYS HWN*/

                  /* homogamy*/
                   i.y*h if cps == 1


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen xe_hcps1962 = exp(f40h)

       foreach num of numlist 1964/2003 {
         quietly gen xe_hcps`num' = exp(f40h + f03_IyXh_`num')
       }


       foreach num of numlist 1962 1964/2003 {
         quietly egen e_hcps`num' = mean(xe_hcps`num')
       }



   drop f40* f03*






  *** GRAPH  ***

    keep e_*

    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_dc1cps e_dc2cps e_dc3cps e_dc4cps e_dc1cen e_dc2cen e_dc3cen e_dc4cen
                 e_hcen e_hcps , i(id) j(year) ;

    #delimit cr

label var e_dc1cen  "lt 10/10-11, Census"
label var e_dc2cen  "10-11/12, Census"
label var e_dc3cen  "12/13-15, Census"
label var e_dc4cen  "13-15/ge 16, Census"
label var e_dc1cps  "lt 10/10-11, CPS"
label var e_dc2cps  "10-11/12, CPS"
label var e_dc3cps  "12/13-15, CPS"
label var e_dc4cps  "13-15/ge 16, CPS"


    ***These are in b&w



     #delimit ;
     twoway connected  e_dc1cps e_dc2cps e_dc1cen e_dc2cen  year,
                      yscale(log r(.28 .6)) clstyle(p2 p2 p2 p2 p2 p2) clpattern(l l - - )
                      ylabel(.3(.05).6, grid format(%3.2fc) labsize(small))
                      scheme(s1color)
                      msymbol(Dh T O Oh)
                      msize(medsmall medium small small)
                      clpattern(llll) clcolor(gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0)
                      graphregion(fcolor(gs16)) plotregion(style(none))
                      title(" ", size(medlarge) color(gs0)) sub(" ")
                      xscale(r(1940 2003))
                      xlabel(1940 1945 1950 1955 1960 1965 1970 1975 1980 1985 1990 1995 2000, labsize(small))
                      ytitle("Odds of Crossing", size(small)) xtitle("Year", size(small))
                      legend(rows(2) size(small)) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
    #delimit cr
    graph export analysis_prev_4.wmf, replace



     #delimit ;
     twoway connected e_dc3cps e_dc4cps e_dc3cen e_dc4cen year,
                      yscale(log r(.28 .6)) clstyle(p2 p2 p2 p2 p2 p2) clpattern(l l - - )
                      ylabel(.3(.05).6, grid format(%3.2fc) labsize(small))
                      scheme(s1color)
                      msymbol(O X Oh O)
                      msize(medium medium small small)
                      clpattern(llll) clcolor(gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0)
                      graphregion(fcolor(gs16)) plotregion(style(none))
                      title(" ", size(medlarge) color(gs0)) sub(" ")
                      xscale(r(1940 2003))
                      xlabel(1940 1945 1950 1955 1960 1965 1970 1975 1980 1985 1990 1995 2000, labsize(small))
                      ytitle("Odds of Crossing", size(small)) xtitle("Year", size(small))
                      legend(rows(2) size(small)) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
    #delimit cr
    graph export analysis_prev_5.wmf, replace



    cd "F:\Schwartz\cps_historical\graphs"
    #delimit ;
    twoway connected  e_hcen e_hcps year, yscale(log) clpattern(l l )
                                    msymbol(Dh T O X)
                                    msize(small small med med)
                                    xlabel(#15) graphregion(fcolor(gs16)) plotregion(style(none))
                                    sub("Prevailing Marriages", size(medsmall))
                                    note("SOURCES: Current Population Survey (CPS) and Census data")
                                    clpattern(llll) clcolor(gs0 gs0 gs3 gs0) mcolor(gs0 gs0 gs1 gs0) ;
    #delimit cr
    graph export analysis_prev_6.wmf, replace

