#delimit ;
*desc.do ;
capture log close ;
version 8.0 ;
log using "F:\Schwartz\cps_historical\do\desc.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 400m ;
set matsize 800 ;



*** In this program I run descriptive statistics for the
     revised version of "Trends in Educational Assortative
     Marriage From 1940 to 2003".

    ;


#delimit cr


********************************
* PART 1: PREVAILING MARRIAGES *
********************************



   use "F:\Schwartz\cps_historical\data\prevmar_tabpub.dta"

   gen cps = (cen == 0)


   *************
   * MARGINALS *
   *************

   preserve
   collapse (sum) WEIGHT if cps == 0, by(wedc y)
   sort y wedc
   list
   restore

   preserve
   collapse (sum) WEIGHT if cps == 0, by(hedc y)
   sort y hedc
   list
   restore



   ****************
   * CENSUS TABLE *
   ****************



   ***UNWEIGHTED

      preserve
      collapse (sum) freq if cps == 0, by(wedc hedc y)
      bysort y: tab wedc hedc [w=freq], cell
      restore

   ***WEIGHTED

      preserve
      collapse (sum) WEIGHT if cps == 0, by(wedc hedc y)
      *Importance weights produce accurate cell percentages here
       bysort y: tab wedc hedc [iw=WEIGHT], cell
      restore



   ****************
   * SAMPLE SIZES *
   ****************

   preserve
   collapse (sum) WEIGHT, by(y cps)
   sort y cps
   list
   restore



   ********************
   * CREATE VARIABLES *
   ********************


   gen h = (hedc == wedc)
   gen hyp = (hedc > wedc)

   *check
   tab hedc wedc [w=freq] if h == 1
   tab hedc wedc [w=freq] if hyp == 1



   ***Education specific homogamy

      gen h1 = (hed == wed & hed == 1)
      gen h2 = (hed == wed & hed == 2)
      gen h3 = (hed == wed & hed == 3)
      gen h4 = (hed == wed & hed == 4)
      gen h5 = (hed == wed & hed == 5)



   ***Make the crossing variables

       gen dc1 = 0
       replace dc1 = 1 if (wed < 2 & hed>= 2) | (hed< 2 & wed >= 2)

       gen dc2 = 0
       replace dc2 = 1 if (wed < 3 & hed>= 3) | (hed< 3 & wed >= 3)

       gen dc3 = 0
       replace dc3= 1 if (wed < 4 & hed>= 4) | (hed< 4 & wed >= 4)

       gen dc4 = 0
       replace dc4 = 1 if (wed < 5 & hed>= 5) | (hed< 5 & wed >= 5)


   *check
   forvalues i = 1/4 {
     tab hedc wedc [w=freq] if dc`i' == 1
   }


  ***Distance

     gen d = abs(wed-hed)
     gen d2 = (d >= 2)


   *check
   tab hedc wedc [w=freq] if dc2 == 1



   preserve

       keep d2 y WEIGHT cps

       collapse d2 [w=WEIGHT], by(y cps)

   replace d2 = d2*100

   gen dcps = d2 if cps == 1
   gen dcen = d2 if cps == 0


   label var dcps "CPS"
   label var dcen "Census"

   list y dcps dcen



   #delimit ;

   *This one is in color ;


     twoway connected dcps dcen y, c(l)

     xlabel(#15) title("Percent Crossing 2 or More Educational Categories") sub("Prevailing Marriages (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year") ysc(r(10 22)) ylabel(10(2)22, grid)
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.") ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc1.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected dcps dcen y, c(l)
     scheme(s1color)
     msymbol(O T S D)
     msize(med med large medlarge) ysc(r(10 22)) ylabel(10(2)22, grid)
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
     ytitle("Percent (%)") xtitle("Year")
   /*  note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/
     legend(off) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc2.wmf, replace ;





     restore ;



   #delimit cr


   preserve

       keep h y WEIGHT cps

       collapse h [w=WEIGHT], by(y cps)

   replace h = h*100

   gen hcps = h if cps == 1
   gen hcen = h if cps == 0

   label var hcps "CPS"
   label var hcen "Census"

   list y hcps hcen


   #delimit ;

   *This one is in color ;

     replace h = h*100 ;

     twoway connected hcps hcen y, c(l)

     xlabel(#15) title("Percent Homogamous") sub("Prevailing Marriages (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year") ysc(r(45 60)) ylabel(45(5)60)
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.") ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc3.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected hcps hcen y, c(l)
     scheme(s1color)
     msymbol(O T S D)
     msize(med med large medlarge) ysc(r(45 60)) ylabel(45(5)60, grid)
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
     ytitle("Percent (%)") xtitle("Year")
   /*  note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/
     legend(off) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc4.wmf, replace ;

     list if cps == 0 ;


     restore ;




   #delimit cr


  preserve

     *** GRAPH  ***



       keep hyp y WEIGHT cps h

       keep if h == 0


       collapse hyp [w=WEIGHT], by(y cps)

   replace hyp = hyp*100

   gen hypcps = hyp if cps == 1
   gen hypcen = hyp if cps == 0

   label var hypcps "CPS"
   label var hypcen "Census"


   list y hypcps hypcen



   #delimit ;

   *This one is in color ;

     replace hyp = hyp*100 ;

     twoway connected hypcps hypcen y, c(l)

     xlabel(#15) title("Percent Hypergamous, Given Heterogamy") sub("Prevailing Marriages (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D) ysc(r(45 65)) ylabel(45(5)65)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.") ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc5.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected hypcps hypcen y, c(l)
     scheme(s1color)
     msymbol(O T S D)
     msize(med med large medlarge)
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15) /*title("Figure 5. Percent Hypergamous Given Heterogamy by Data Source", size(med) color(gs0)) sub("Prevailing Marriages, U.S. 1940-2003")*/
     ytitle("Percent (%)") xtitle("Year") ysc(r(45 65)) ylabel(45(5)65, grid)
  /*   note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/
     legend(off) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc6.wmf, replace ;



 #delimit cr



  restore


  preserve

   #delimit cr



     *** GRAPH  ***



       keep dc1 dc2 dc3 dc4 y WEIGHT cps h


       collapse dc1 dc2 dc3 dc4 [w=WEIGHT], by(y)

   replace dc1 = dc1*100
   replace dc2 = dc2*100
   replace dc3 = dc3*100
   replace dc4 = dc4*100


   lab var dc1 "<10/10+"
   lab var dc2 "<12/12+"
   lab var dc3 "<13/13+"
   lab var dc4 "<16/16+"

   #delimit ;

   *This one is in color ;


     twoway connected dc1 dc2 dc3 dc4 y, c(l)

     xlabel(#15) title("Percent Crossing an Educational Barrier by Education Level") sub("Prevailing Marriages")
     ytitle("Percent (%)") xtitle("Year")
      mcolor(purple lime blue red  emerald  gs5)
     clcolor(purple lime blue red  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)
     note("SOURCES: Current Population Survey (CPS) and Census data")  ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc7.wmf, replace ;




 #delimit cr



  restore



preserve

   #delimit cr



     *** GRAPH  ***


   ***Education specific homogamy


      drop h?

      foreach num of numlist 1/5 {
       gen     h`num' = 1 if hed == wed & wed == `num'
       replace h`num' = 0 if hed ~= wed & wed == `num'
      }



       keep h1 h2 h3 h4 h5 y WEIGHT cps

       collapse h1 h2 h3 h4 h5 [w=WEIGHT], by(y)

   replace h1 = h1*100
   replace h2 = h2*100
   replace h3 = h3*100
   replace h4 = h4*100
   replace h5 = h5*100

   lab var h1 "<10"
   lab var h2 "10-11"
   lab var h3 "12"
   lab var h4 "13-15"
   lab var h5 "16+"


   #delimit ;

   *This one is in color ;

     twoway connected h1 h2 h3 h4 h5 y, c(l)

     xlabel(#15) title("Percent Homogamous by Wife's Education") sub("Prevailing Marriages")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)  legend(rows(1))
     note("SOURCES: Current Population Survey (CPS) and Census data")  ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc8.wmf, replace ;

   *This one is black and white

 #delimit ;
     twoway connected h1 h2 h3 h4 h5 y,
     scheme(s2manual)
     graphregion(fcolor(gs16) style(none) lstyle(none) color(white))
     xlabel(#15)
     msize(med medsmall medsmall med medlarge)
     ytitle("Percent (%)") xtitle("Year")   ysc(r(20 80)) ylabel(20(10)85, grid)
     legend(off) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc9.wmf, replace ;

 #delimit cr


  restore


preserve

   #delimit cr



     *** GRAPH  ***


   ***Education specific homogamy


      drop h?

      foreach num of numlist 1/5 {
       gen     h`num' = 1 if hed == wed & hed == `num'
       replace h`num' = 0 if hed ~= wed & hed == `num'
      }



       keep h1 h2 h3 h4 h5 y WEIGHT cps


       collapse h1 h2 h3 h4 h5 [w=WEIGHT], by(y)

   replace h1 = h1*100
   replace h2 = h2*100
   replace h3 = h3*100
   replace h4 = h4*100
   replace h5 = h5*100

   lab var h1 "<10"
   lab var h2 "10-11"
   lab var h3 "12"
   lab var h4 "13-15"
   lab var h5 "16+"


   #delimit ;

   *This one is in color ;

     twoway connected h1 h2 h3 h4 h5 y, c(l)

     xlabel(#15) title("Percent Homogamous by Husband's Education") sub("Prevailing Marriages")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)  legend(rows(1))
     note("SOURCES: Current Population Survey (CPS) and Census data")  ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc10.wmf, replace ;

   *This one is black and white

 #delimit ;
     twoway connected h1 h2 h3 h4 h5 y,
     scheme(s2manual)
     graphregion(fcolor(gs16) style(none) lstyle(none) color(white))
     xlabel(#15)
     msize(med medsmall medsmall med medlarge)
     ytitle("Percent (%)", size(*.93)) xtitle("Year")   ysc(r(20 80)) ylabel(20(10)85, grid labsize(*.93))
     legend(rows(1)) ysize(4.1) xsize(5.5) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc11.wmf, replace ;

 #delimit cr


  restore


  clear
  set mem 600m






**********************
* PART 2: NEWLYWEDS  *
**********************



   use "F:\Schwartz\cps_historical\data\newly_tabpub.dta"

   gen cps = (cen == 0)

   tab y cps [w=freq]
   display _N


   collapse (sum) WEIGHT freq, by(wedc hedc y cps)

   replace y = y-1900

   gen yc = y

   recode yc  71/74=72.5 75/79=77 80/84=82.5 85/89=87 90/95=92 if cps == 1


   tab yc


   tab y cps [w=freq]
   display _N

   preserve
   collapse (sum) freq, by(y cps)
   display _N
   restore


   *************
   * MARGINALS *
   *************

   preserve
   collapse (sum) WEIGHT if cps == 0 | y == 88 | y == 94, by(wedc y)
   sort y wedc
   list
   restore

   preserve
   collapse (sum) WEIGHT if cps == 0 | y == 88 | y == 94, by(hedc y)
   sort y hedc
   list
   restore





   collapse (sum) freq WEIGHT, by(wed hed yc cps)





   ********************
   * CREATE VARIABLES *
   ********************


   gen h = (hedc == wedc)
   gen hyp = (hedc > wedc)
   replace yc = yc + 1900
   rename yc y


  ***Distance

     gen d = abs(wed-hed)
     gen d2 = (d >= 2)

  preserve

       keep d2 y WEIGHT cps

       collapse d2 [w=WEIGHT], by(y cps)


   display _N
   set obs 10
   replace y = 2003 in 10

   replace d2 = d2*100

   gen dcps = d2 if cps == 1
   gen dcen = d2 if cps == 0


   label var dcps "CPS"
   label var dcen "Census"

   list y dcps dcen


   #delimit ;

   *This one is in color ;


     twoway connected dcps dcen y, c(l)

     xlabel(#15) title("Percent Crossing 2 or More Educational Categories") sub("Newlyweds (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year") ysc(r(10 22)) ylabel(10(2)22, grid)
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.") ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc12.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected dcps dcen y, c(l)
     scheme(s1color)
     msymbol(O T S D)
     msize(med med large medlarge) ysc(r(10 22)) ylabel(10(2)22, grid labsize(*.93))
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15, labsize(*.93))   title(" ", size(medlarge) color(gs0)) sub(" ")
     ytitle("Percent (%)", size(*.93)) xtitle("Year", size(*.93))
   /*  note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/
      ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc13.wmf, replace ;




   #delimit cr

    restore




   preserve

       keep h y WEIGHT cps

       collapse h [w=WEIGHT], by(y cps)

   replace h = h*100

   gen hcps = h if cps == 1
   gen hcen = h if cps == 0

   label var hcps "CPS"
   label var hcen "Census"

   list y hcps hcen

   set obs 10
   replace y = 2003 in 10


   #delimit ;

   *This one is in color ;

     replace h = h*100 ;

     twoway connected hcps hcen y, c(l)

     xlabel(#15) title("Percent Homogamous") sub("Newlyweds (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D) ysc(r(45 60)) ylabel(45(5)60)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.") ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc14.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected hcps hcen y, c(l)
     scheme(s1color)
     msymbol(O T S D)
     msize(med med large medlarge) ysc(r(45 60)) ylabel(45(5)60, grid)
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15) /*title("Figure 4. Percent Homogamous by Data Source", size(medlarge) color(gs0)) sub("Newlyweds, U.S. 1940-2003")*/
     ytitle("Percent (%)") xtitle("Year")
    /* note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/ ;

      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc15.wmf, replace ;





     restore ;



   #delimit cr

    preserve


     *** GRAPH  ***



       keep hyp y WEIGHT cps h

       keep if h == 0


       collapse hyp [w=WEIGHT], by(y cps)

   replace hyp = hyp*100

   gen hypcps = hyp if cps == 1
   gen hypcen = hyp if cps == 0

   label var hypcps "CPS"
   label var hypcen "Census"

   set obs 10
   replace y = 2003 in 10


   list y hypcps hypcen

   #delimit ;

   *This one is in color ;

     replace hyp = hyp*100 ;

     twoway connected hypcps hypcen y, c(l)

     xlabel(#15) title("Percent Hypergamous, Given Heterogamy") sub("Newlyweds (Wives 18-40)")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D) ysc(r(45 65)) ylabel(45(5)65)
     msize(medlarge medlarge large medlarge)
     note("SOURCES: Current Population Survey (CPS) and Census data")  ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc16.wmf, replace ;


   *This one is black and white

     #delimit ;
     twoway connected hypcps hypcen y, c(l)
     msymbol(O T S D)
     scheme(s1color)
     msize(med med large medlarge)
     clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15) /*title("Figure 6. Percent Hypergamous Given Heterogamy by Data Source", size(med) color(gs0)) sub("Newlyweds, U.S. 1940-2003")*/
     ytitle("Percent (%)") xtitle("Year") ysc(r(45 65)) ylabel(45(5)65, grid)
   /*  note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, and ge 16 years of schooling.")*/ ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc17.wmf, replace ;



     #delimit cr

     restore





     *** GRAPH  ***


*      preserve


   ***Education specific homogamy


      foreach num of numlist 1/5 {
       gen     h`num' = 1 if hed == wed & wed == `num'
       replace h`num' = 0 if hed ~= wed & wed == `num'
      }


       keep h1 h2 h3 h4 h5 y WEIGHT cps



       collapse h1 h2 h3 h4 h5 [w=WEIGHT], by(y)

   replace h1 = h1*100
   replace h2 = h2*100
   replace h3 = h3*100
   replace h4 = h4*100
   replace h5 = h5*100

   lab var h1 "<10"
   lab var h2 "10-11"
   lab var h3 "12"
   lab var h4 "13-15"
   lab var h5 "16+"


   set obs 10
   replace y = 2003 in 10

   #delimit ;

   *This one is in color ;

     twoway connected h1 h2 h3 h4 h5 y, c(l)

     xlabel(#15) title("Percent Homogamous by Education Level") sub("Prevailing Marriages")
     ytitle("Percent (%)") xtitle("Year")
     mcolor(blue red purple lime  emerald  gs5)
     clcolor(blue red purple lime  emerald  gs5)
     clwidth(medthick medthick medthick medthick)
     msymbol(O T S D)
     note("SOURCES: Current Population Survey (CPS) and Census data")  ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc18.wmf, replace ;

   *This one is black and white

     #delimit ;
     twoway connected h1 h2 h3 h4 h5 y,
     scheme(s1mono)
     clstyle(p1 p1 p1 p1 p1) clwidth(thin thin thin thin thin)
     graphregion(fcolor(gs16)) plotregion(style(none))
     xlabel(#15,labsize(*.93))
     msize(med medsmall medsmall med medlarge)
     ytitle("Percent (%)", size(*.93)) xtitle("Year")   ysc(r(20 80)) ylabel(20(10)85, grid labsize(*.93))
     legend(rows(1)) ysize(4.1) xsize(5.5) ;


      cd "F:\Schwartz\cps_historical\graphs" ;
      graph export desc19.wmf, replace ;
 #delimit cr



log close

